@@ -132,6 +132,13 @@ FreePixmap(PixmapPtr pPixmap)
     free(pPixmap);
 }
 
+void PixmapUnshareSlavePixmap(PixmapPtr slave_pixmap)
+{
+     int ihandle = -1;
+     ScreenPtr pScreen = slave_pixmap->drawable.pScreen;
+     pScreen->SetSharedPixmapBacking(slave_pixmap, ((void *)(long)ihandle));
+}
+
 PixmapPtr PixmapShareToSlave(PixmapPtr pixmap, ScreenPtr slave)
 {
     PixmapPtr spix;
@@ -173,6 +180,9 @@ PixmapStartDirtyTracking(PixmapPtr src,
 {
     ScreenPtr screen = src->drawable.pScreen;
     PixmapDirtyUpdatePtr dirty_update;
+    RegionPtr damageregion;
+    RegionRec dstregion;
+    BoxRec box;
 
     dirty_update = calloc(1, sizeof(PixmapDirtyUpdateRec));
     if (!dirty_update)
@@ -205,6 +215,24 @@ PixmapStartDirtyTracking(PixmapPtr src,
         return FALSE;
     }
 
+    /* Damage destination rectangle so that the destination pixmap contents
+     * will get fully initialized
+     */
+    box.x1 = dirty_update->x;
+    box.y1 = dirty_update->y;
+    if (dirty_update->rotation == RR_Rotate_90 ||
+        dirty_update->rotation == RR_Rotate_270) {
+        box.x2 = dirty_update->x + slave_dst->drawable.height;
+        box.y2 = dirty_update->y + slave_dst->drawable.width;
+    } else {
+        box.x2 = dirty_update->x + slave_dst->drawable.width;
+        box.y2 = dirty_update->y + slave_dst->drawable.height;
+    }
+    RegionInit(&dstregion, &box, 1);
+    damageregion = DamageRegion(dirty_update->damage);
+    RegionUnion(damageregion, damageregion, &dstregion);
+    RegionUninit(&dstregion);
+
     DamageRegister(&src->drawable, dirty_update->damage);
     xorg_list_add(&dirty_update->ent, &screen->pixmap_dirty_list);
     return TRUE;
