@@ -56,7 +56,7 @@ check_signed_number_format_test(long int number)
     FormatInt64(number, string);
     if(strncmp(string, expected, 21) != 0) {
         fprintf(stderr, "Failed to convert %jd to decimal string (expected %s but got %s)\n",
-                number, expected, string);
+                (intmax_t) number, expected, string);
         return FALSE;
     }
 
@@ -93,7 +93,7 @@ check_number_format_test(long unsigned int number)
     FormatUInt64(number, string);
     if(strncmp(string, expected, 21) != 0) {
         fprintf(stderr, "Failed to convert %ju to decimal string (%s vs %s)\n",
-                number, expected, string);
+                (intmax_t) number, expected, string);
         return FALSE;
     }
 
@@ -101,7 +101,7 @@ check_number_format_test(long unsigned int number)
     FormatUInt64Hex(number, string);
     if(strncmp(string, expected, 17) != 0) {
         fprintf(stderr, "Failed to convert %ju to hexadecimal string (%s vs %s)\n",
-                number, expected, string);
+                (intmax_t) number, expected, string);
         return FALSE;
     }
 
@@ -113,6 +113,9 @@ double float_tests[] = { 0, 5, 0.1, 0.01, 5.2342, 10.2301,
                          -1, -2.00, -0.6023, -1203.30
                         };
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Woverflow"
+
 static void
 number_formatting(void)
 {
@@ -149,9 +152,12 @@ number_formatting(void)
     for (i = 0; i < sizeof(float_tests) / sizeof(float_tests[0]); i++)
         assert(check_float_format_test(float_tests[i]));
 }
+#pragma GCC diagnostic pop
 
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wformat-security"
+#pragma GCC diagnostic ignored "-Wformat"
+#pragma GCC diagnostic ignored "-Wformat-extra-args"
 static void logging_format(void)
 {
     const char *log_file_path = "/tmp/Xorg-logging-test.log";
@@ -173,9 +179,14 @@ static void logging_format(void)
     LogInit(log_file_path, NULL);
     assert(f = fopen(log_file_path, "r"));
 
-#define read_log_msg(msg) \
-    fgets(read_buf, sizeof(read_buf), f); \
-    msg = strchr(read_buf, ']') + 2; /* advance past [time.stamp] */
+#define read_log_msg(msg) do {                                  \
+        msg = fgets(read_buf, sizeof(read_buf), f);             \
+        assert(msg != NULL);                                   \
+        msg = strchr(read_buf, ']');                            \
+        assert(msg != NULL);                                    \
+        assert(strlen(msg) > 2);                                \
+        msg = msg + 2; /* advance past [time.stamp] */          \
+    } while (0)
 
     /* boring test message */
     LogMessageVerbSigSafe(X_ERROR, -1, "test message\n");
@@ -220,14 +231,12 @@ static void logging_format(void)
     assert(strcmp(logmsg, "(EE) substituted string\n") == 0);
 
     /* Invalid format */
-#warning Ignore compiler warning below "lacks type at end of format".  This is intentional.
     LogMessageVerbSigSafe(X_ERROR, -1, "%4", 4);
     read_log_msg(logmsg);
     assert(strcmp(logmsg, "(EE) ") == 0);
     LogMessageVerbSigSafe(X_ERROR, -1, "\n");
     fseek(f, 0, SEEK_END);
 
-#warning Ignore compiler warning below "unknown conversion type character".  This is intentional.
     /* %hld is bogus */
     LogMessageVerbSigSafe(X_ERROR, -1, "%hld\n", 4);
     read_log_msg(logmsg);
@@ -343,7 +352,11 @@ static void logging_format(void)
     ptr = 1;
     do {
         char expected[30];
+#ifdef __sun /* Solaris doesn't autoadd "0x" to %p format */
+        sprintf(expected, "(EE) 0x%p\n", (void*)ptr);
+#else
         sprintf(expected, "(EE) %p\n", (void*)ptr);
+#endif
         LogMessageVerbSigSafe(X_ERROR, -1, "%p\n", (void*)ptr);
         read_log_msg(logmsg);
         assert(strcmp(logmsg, expected) == 0);
